@@ -5,7 +5,7 @@ import pdfminer.layout
 import pdfminer.high_level
 import sys
 from time import sleep
-from .exceptions import PdfError
+from .exceptions import ConversionError
 
 OUTPUT_TYPES = (
     (".htm", "html"),
@@ -96,9 +96,9 @@ def convert_pdf_to_html(pdf_path, html_path, num_tries=3):
             if i < 2:
                 continue
             else:
-                raise PdfError(f'error converting "{pdf_path}" to html: {e}')
+                raise ConversionError(f'error converting "{pdf_path}" to html: {e}')
     else:
         error_message = f'error converting "{pdf_path}" to html'
         Path(html_path).save(obj=error_message)
-        raise PdfError(error_message)
+        raise ConversionError(error_message)
     return html_path
